@@ -98,12 +98,13 @@ class QuartKroket(Quart):
         self.config['SESSION_PROTECTION'] = session_protection
         Session(self)
 
-    def setup_keycloak(self, client_id: str, client_secret: str, configuration: str):
+    def setup_keycloak(self, client_id: str, client_secret: str, configuration: str, **opts):
         from quart_keycloak import Keycloak
         self.keycloak = Keycloak(self, **{
             "client_id": client_id,
             "client_secret": client_secret,
-            "configuration": configuration
+            "configuration": configuration,
+            **opts
         })
 
         @self.route('/oidc/login')
